( cd bin ; rm -rf dnsdomainname )
( cd bin ; ln -sf hostname dnsdomainname )
( cd sbin ; rm -rf ramsize )
( cd sbin ; ln -sf rdev ramsize )
( cd sbin ; rm -rf swapdev )
( cd sbin ; ln -sf rdev swapdev )
( cd sbin ; rm -rf swapoff )
( cd sbin ; ln -sf swapon swapoff )
( cd sbin ; rm -rf vidmode )
( cd sbin ; ln -sf rdev vidmode )
( cd sbin ; rm -rf mount )
( cd sbin ; ln -sf /bin/mount mount )
( cd sbin ; rm -rf umount )
( cd sbin ; ln -sf /bin/umount umount )
( cd sbin ; rm -rf rootflags )
( cd sbin ; ln -sf rdev rootflags )
( cd sbin ; rm -rf update )
( cd sbin ; ln -sf bdflush update )
( cd usr/bin ; rm -rf more )
( cd usr/bin ; ln -sf /bin/more more )
